@@ -11,23 +11,23 @@ use tokio_tungstenite::tungstenite::Message as WSMessage;
 use tracing::{debug, error, info, warn};
 
 /// Type alias to communicate a stream's unique String identifier that can be used to route messages
-/// from the [ConnectionHandler] to the relevant downstream consumer.
+/// from the [`ConnectionHandler`] to the relevant downstream consumer.
 pub type StreamRoutingId = String;
 
 /// Manages all connection related actions. This includes maintaining the WebSocket connection;
-/// re-connections; actioning [Subscription] requests received from an ExchangeClient; consuming
+/// re-connections; actioning [`Subscription`] requests received from an ExchangeClient; consuming
 /// incoming exchange messages from the WebSocket connection and routing them to the appropriate
 /// downstream consumer.
 pub struct ConnectionHandler<Message, Sub> {
-    /// An established [WSStream] connection that all ExchangeClient <--> ConnectionHandler
+    /// An established [`WSStream`] connection that all ExchangeClient <--> ConnectionHandler
     /// communication goes through.
     pub ws_conn: WSStream,
-    /// [Subscription] request channel receiver. Receives a tuple of [Subscription] and a data channel
+    /// [`Subscription`] request channel receiver. Receives a tuple of [`Subscription`] and a data channel
     /// transmitter. This data channel transmitter is used to route messages relating to a particular
-    /// [Subscription] back to the subscriber via the ExchangeClient implementation.
+    /// [`Subscription`] back to the subscriber via the ExchangeClient implementation.
     pub subscription_rx: mpsc::Receiver<(Sub, mpsc::UnboundedSender<Message>)>,
-    /// Map containing the data channel transmitter for every [Subscription] actioned. The map's
-    /// [StreamRoutingId] key is used to identify which data channel to transmit an incoming
+    /// Map containing the data channel transmitter for every [`Subscription`] actioned. The map's
+    /// [`StreamRoutingId`] key is used to identify which data channel to transmit an incoming
     /// exchange message to.
     pub exchange_data_txs: HashMap<StreamRoutingId, mpsc::UnboundedSender<Message>>,
 }
@@ -37,7 +37,7 @@ where
     Sub: Debug + Subscription + StreamIdentifier + Serialize + Send + Sync,
     Message: Debug + StreamIdentifier + DeserializeOwned + Send + Sync,
 {
-    /// Constructs a new [ConnectionHandler] instance using the [WSStream] connection provided.
+    /// Constructs a new [`ConnectionHandler`] instance using the [`WSStream`] connection provided.
     pub fn new(
         ws_conn: WSStream,
         subscription_rx: mpsc::Receiver<(Sub, mpsc::UnboundedSender<Message>)>,
@@ -49,9 +49,9 @@ where
         }
     }
 
-    /// Consumes two types of incoming messages [Subscription] requests received from an
+    /// Consumes two types of incoming messages [`Subscription`] requests received from an
     /// ExchangeClient implementor instance, and also the data received from an exchange as a
-    /// result of a [Subscription]. This function handles the actioning of [Subscription] requests,
+    /// result of a [`Subscription`]. This function handles the actioning of [`Subscription`] requests,
     /// and routes the exchange data to the associated downstream subscriber.
     pub async fn manage(mut self) {
         loop {
@@ -72,7 +72,10 @@ where
                     let ws_message = match ws_message_result {
                         Ok(ws_message) => ws_message,
                         Err(err) => {
-                            warn!("Skipping message Result due to unexpected error: {:?}", err);
+                            warn!(
+                                error = &*format!("{:?}", err),
+                                "skipping message due to unexpected error"
+                            );
                             continue
                         },
                     };
@@ -83,17 +86,28 @@ where
                             match serde_json::from_str::<Message>(&*text.clone()) {
                                 Ok(message) => message,
                                 Err(err) => {
-                                    error!("Failure to deserialise message: {:?} due to error: {:?}", text, err);
+                                    error!(
+                                        error = &*format!("{:?}", err),
+                                        payload = &*text,
+                                        "failed to deserialise incoming exchange message"
+                                    );
                                     continue;
                                 },
                                 }
                         },
                         WSMessage::Binary(binary) => {
-                            warn!("Received unexpected binary message: {:?}", binary);
+                            warn!(
+                                payload = &*format!("{:?}", binary),
+                                "received unexpected binary message"
+                            );
                             continue;
                         },
                         WSMessage::Close(close_frame) => {
-                            info!("WebSocket connection closed with final frame: {:?}", close_frame);
+                            info!(
+                                payload = &*format!("{:?}", close_frame),
+                                why = "received WebSocket::Close final frame",
+                                "WebSocket connection closed"
+                            );
                             break;
                         }
                         _ => continue,
@@ -103,7 +117,10 @@ where
                     let routing_id = match exchange_message.get_stream_id() {
                         Identifier::Yes(routing_id) => routing_id,
                         Identifier::No => {
-                            debug!("Ignoring received message due to no route: {:?}", exchange_message);
+                            debug!(
+                                payload = &*format!("{:?}", exchange_message),
+                                "skipping message due to no routing id",
+                            );
                             continue
                         },
                     };
@@ -113,7 +130,12 @@ where
 
                     // Route Message to associated downstream subscriber
                     if data_tx.send(exchange_message).is_err() {
-                        info!("Receiver for: {:?} has been dropped - closing stream", &routing_id);
+                        debug!(
+                            action = "closing stream",
+                            routing_id = &*routing_id,
+                            why = "Receiver for Exchange message has been dropped",
+                            "cannot send Exchange message to downstream consumer"
+                        );
                         self.exchange_data_txs.remove_entry(&routing_id);
                         continue;
                     }
@@ -122,19 +144,16 @@ where
         }
     }
 
-    /// Action a [Subscription] request received from an ExchangeClient. An exchange data
+    /// Action a [`Subscription`] request received from an ExchangeClient. An exchange data
     /// transmitter is inserted into the exchange_data_txs map upon subscribing, this is used by
-    /// the [ConnectionHandler] to route incoming exchange messages to the associated downstream
+    /// the [`ConnectionHandler`] to route incoming exchange messages to the associated downstream
     /// consumers.
     async fn action_subscription_request(
         mut self,
         sub_request: Sub,
         data_tx: mpsc::UnboundedSender<Message>,
     ) -> Self {
-        info!(
-            "Received Subscription request from ExchangeClient: {:?}",
-            sub_request
-        );
+        info!("received Subscription request from ExchangeClient: {:?}", sub_request);
 
         // Identify StreamRoutingId of the Subscription
         let routing_id = match sub_request.get_stream_id() {
@@ -165,7 +184,7 @@ where
         self
     }
 
-    /// Subscribe asynchronously to a WebSocket data stream using the [Subscription] provided.
+    /// Subscribe asynchronously to a WebSocket data stream using the [`Subscription`] provided.
     pub async fn subscribe(&mut self, subscription: Sub) -> Result<(), ClientError> {
         self.ws_conn
             .send(WSMessage::text(subscription.as_text()?))
@@ -174,20 +193,16 @@ where
         Ok(())
     }
 
-    /// Retrieves the data transmitter associated with a [StreamRoutingId] from the
-    /// [ConnectionHandler]'s exchange_data_tx map.
+    /// Retrieves the data transmitter associated with a [`StreamRoutingId`] from the
+    /// [`ConnectionHandler`]'s exchange_data_tx map.
     fn retrieve_relevant_data_transmitter(
         &mut self,
         routing_id: &String,
     ) -> &mut mpsc::UnboundedSender<Message> {
         self.exchange_data_txs.get_mut(routing_id).expect(
-            format!(
-                "Message with StreamRoutingId: {:?} has been received \
-                                    without a relevant exchange_data_tx in the map to route \
-                                    it to",
-                routing_id
-            )
-            .as_str(),
+            &*format!(
+                "Message with StreamRoutingId: {:?} has been received without a relevant \
+                exchange_data_tx in the map to route it to", routing_id)
         )
     }
 }
