@@ -2,14 +2,14 @@ use chrono::{DateTime, Utc};
 use serde::{Deserialize, Serialize};
 use ta::{Close, High, Low, Open, Volume};
 
-#[derive(Debug, Deserialize, Serialize, PartialOrd, PartialEq, Clone)]
+#[derive(Clone, PartialEq, PartialOrd, Debug, Serialize, Deserialize)]
 pub enum MarketData {
     Trade(Trade),
     Candle(Candle),
 }
 
 /// Normalised Trade model to be returned from an ExchangeClient implementor instance.
-#[derive(Debug, Deserialize, Serialize, PartialOrd, PartialEq, Clone)]
+#[derive(Clone, PartialEq, PartialOrd, Debug, Serialize, Deserialize)]
 pub struct Trade {
     pub trade_id: String,
     pub timestamp: DateTime<Utc>,
@@ -19,15 +19,15 @@ pub struct Trade {
     pub buyer: BuyerType,
 }
 
-/// Defines if the buyer in a [Trade] is a market maker.
-#[derive(Debug, Deserialize, Serialize, PartialOrd, PartialEq, Clone)]
+/// Defines if the buyer in a [`Trade`] is a market maker.
+#[derive(Clone, Eq, PartialEq, Ord, PartialOrd, Hash, Debug, Serialize, Deserialize)]
 pub enum BuyerType {
     MarketMaker,
     Taker,
 }
 
-/// Defines the possible intervals that a [Candle] represents.
-#[derive(Debug, Deserialize, Serialize, PartialOrd, PartialEq, Clone)]
+/// Defines the possible intervals that a [`Candle`] represents.
+#[derive(Clone, Eq, PartialEq, Ord, PartialOrd, Hash, Debug, Serialize, Deserialize)]
 pub enum Interval {
     Minute1,
     Minute3,
@@ -46,8 +46,8 @@ pub enum Interval {
     Month1,
 }
 
-/// Normalised OHLCV data from an [Interval] with the associated [DateTime] UTC timestamp;
-#[derive(Debug, Deserialize, Serialize, PartialOrd, PartialEq, Clone)]
+/// Normalised OHLCV data from an [`Interval`] with the associated [`DateTime`] UTC timestamp;
+#[derive(Clone, PartialEq, PartialOrd, Debug, Serialize, Deserialize)]
 pub struct Candle {
     pub start_timestamp: DateTime<Utc>,
     pub end_timestamp: DateTime<Utc>,
@@ -102,4 +102,4 @@ impl Volume for Candle {
     fn volume(&self) -> f64 {
         self.volume
     }
-}
+}
\ No newline at end of file
